@@ -6,7 +6,7 @@ from ..strategy import Strategy
 from ..utils import GradientOptimizer
 
 
-class Persistent_ES(Strategy):
+class PersistentES(Strategy):
     def __init__(self, num_dims: int, popsize: int, opt_name: str = "adam"):
         """Persistent ES (Vicol et al., 2021).
         Reference: http://proceedings.mlr.press/v139/vicol21a.html
@@ -16,6 +16,7 @@ class Persistent_ES(Strategy):
         assert not self.popsize & 1, "Population size must be even"
         assert opt_name in ["sgd", "adam", "rmsprop", "clipup"]
         self.optimizer = GradientOptimizer[opt_name](self.num_dims)
+        self.strategy_name = "PersistentES"
 
     @property
     def params_strategy(self) -> chex.ArrayTree:
@@ -26,6 +27,8 @@ class Persistent_ES(Strategy):
             "sigma_limit": 0.1,
             "T": 100,  # Total inner problem length
             "K": 10,  # Truncation length for partial unrolls
+            "init_min": 0.0,
+            "init_max": 0.0,
         }
         params = {**es_params, **self.optimizer.default_params}
         return params
