@@ -5,7 +5,7 @@ from typing import Tuple
 from ..strategy import Strategy
 
 
-class Simple_GA(Strategy):
+class SimpleGA(Strategy):
     def __init__(self, num_dims: int, popsize: int, elite_ratio: float = 0.5):
         """Simple Genetic Algorithm (Such et al., 2017)
         Reference: https://arxiv.org/abs/1712.06567
@@ -14,16 +14,18 @@ class Simple_GA(Strategy):
         super().__init__(num_dims, popsize)
         self.elite_ratio = elite_ratio
         self.elite_popsize = int(self.popsize * self.elite_ratio)
+        self.strategy_name = "SimpleGA"
 
     @property
     def params_strategy(self) -> chex.ArrayTree:
         """Return default parameters of evolution strategy."""
         return {
             "cross_over_rate": 0.5,  # cross-over probability
-            "sigma_init": 0.1,  # initial standard deviation
+            "sigma_init": 0.07,  # initial standard deviation
             "sigma_decay": 0.999,  # anneal standard deviation
             "sigma_limit": 0.01,  # stop annealing if less than this
-            "forget_best": False,  # forget the historical best elites
+            "init_min": 0.0,
+            "init_max": 0.0,
         }
 
     def initialize_strategy(
@@ -37,6 +39,7 @@ class Simple_GA(Strategy):
             maxval=params["init_max"],
         )
         state = {
+            "mean": initialization.mean(axis=0),
             "archive": initialization,
             "fitness": jnp.zeros(self.elite_popsize) + 20e10,
             "sigma": params["sigma_init"],
@@ -54,9 +57,7 @@ class Simple_GA(Strategy):
             if random number > co-rate
           - Additionally add noise on top of all elite parameters
         """
-        rng, rng_eps = jax.random.split(rng)
-        rng, rng_idx_a = jax.random.split(rng)
-        rng, rng_idx_b = jax.random.split(rng)
+        rng, rng_eps, rng_idx_a, rng_idx_b = jax.random.split(rng, 4)
         rng_mate = jax.random.split(rng, self.popsize)
         epsilon = (
             jax.random.normal(rng_eps, (self.popsize, self.num_dims))
@@ -94,9 +95,11 @@ class Simple_GA(Strategy):
         # Update mutation epsilon - multiplicative decay
         state["sigma"] = jax.lax.select(
             state["sigma"] > params["sigma_limit"],
-            state["sigma"] * params["sigma_limit"],
+            state["sigma"] * params["sigma_decay"],
             state["sigma"],
         )
+        # Keep mean across stored archive around for evaluation protocol
+        state["mean"] = state["archive"].mean(axis=0)
         return state
 
 
