@@ -11,6 +11,7 @@ class xNES(Strategy):
         Reference: https://www.jmlr.org/papers/volume15/wierstra14a/wierstra14a.pdf
         Inspired by: https://github.com/chanshing/xnes"""
         super().__init__(num_dims, popsize)
+        self.strategy_name = "xNES"
 
     @property
     def params_strategy(self) -> chex.ArrayTree:
@@ -25,6 +26,8 @@ class xNES(Strategy):
             "eta_bmat": 3
             * (3 + jnp.log(self.num_dims))
             * (1.0 / (5 * self.num_dims * jnp.sqrt(self.num_dims))),
+            "init_min": 0.0,
+            "init_max": 0.0,
         }
         return params
 
@@ -80,7 +83,7 @@ class xNES(Strategy):
         params: chex.ArrayTree,
     ) -> chex.ArrayTree:
         """`tell` performance data for strategy state update."""
-        # By default the ES maximizes the objective
+        # By default the xNES maximizes the objective
         fitness_re = -fitness
         isort = fitness_re.argsort()
         sorted_fitness = fitness_re[isort]
